PyCOVID Package

Usage
-----

getCovidCases() : Get the Rami Krispin Coronavirus Dataset in the original format
getCovidCasesWide(): Wide format - with columns for Confirmed, Death and Recovered Cases
plotCountries(): Plot the country aggregates on world map using Plotly
getIntervalData(): Time re-indexed dataset

Installation
------------

pip install pycovid

Requirements
^^^^^^^^^^^^
Pandas, Numpy and Plotly

Compatibility
-------------

Licence
-------

Authors
-------

PyCOVID was written by Sudharshan Ashok <sudharshan93@gmail.com>
